import java.sql.*; 
import java.util.*;

public class JDBCProbe
{ 
    private static java.util.Properties props = new Properties();
    private static void init(String[] args) throws Exception
    {

        StringBuffer buf = new StringBuffer();
        for (int i = 0; args != null && i < args.length; i++)
        {
            buf.append(args[i]);
            buf.append("\n");
        }

        props.load(new java.io.ByteArrayInputStream(buf.toString().getBytes()));
        //props.list(System.out);
        String product = props.getProperty("product", "");
        String host = props.getProperty("host", "");
        String name = props.getProperty("name", "");
        String port = props.getProperty("port", "");
        String url;
        String drv;
        if (product.equalsIgnoreCase("oracle"))
        {
            if (port.equals(""))
            {
                port = "1521";
            }
            url = "jdbc:oracle:thin:@" + host + ":" + port + ":" + name;
            drv = "oracle.jdbc.driver.OracleDriver";
        }
        else if (product.equalsIgnoreCase("pgsql"))
        {
            if (port.equals(""))
            {
                port = "5432";
            }
            url = "jdbc:postgresql://" + host + ":" + port + "/" + name;
            drv = "org.postgresql.Driver";
        }
        else if (product.equalsIgnoreCase("mssql"))
        {
            if (port.equals(""))
            {
                port = "1433";
            }
            url = "jdbc:sqlserver://" + host + ":" + port + ";DatabaseName=" + name + ";SelectMethod=cursor";
            drv = "com.microsoft.sqlserver.jdbc.SQLServerDriver";
        }
        else if (product.equalsIgnoreCase("sybase"))
        {
            if (port.equals(""))
            {
                port = "5000";
            }
            url = "jdbc:sybase:Tds:" + host + ":" + port + "/" + name;
            drv = "com.sybase.jdbc3.jdbc.SybDriver";
        }
        else
        {
            throw new Exception ("Incorrect product. Must be one of oracle (for Oracle 11g or 12c) OR pgsql (for Postgresql 9.x) OR mssql (for Microsoft SQL Server 2008/2012/2014)");
        }
        props.setProperty("url", url); 
        props.setProperty("driver", drv); 
    }
    public static void main (String[] args) 
    { 
        
        try { 

            if (args.length == 0)
            {
                System.out.println("Usage is java JDBCProbe product=[oracle|mssql|pgsql] name=[database name] user=[database username] password=[database password] host=[database host]");
            }
            System.out.println("");
            System.out.println("");
            init(args);
            // Step 1: Load the JDBC driver. 
            Class.forName(props.getProperty("driver"));

            // Step 2: Establish the connection to the database. 
            String url = props.getProperty("url");
            String usr = props.getProperty("user", "");
            String pwd = props.getProperty("password", "");
            String query = props.getProperty("query", "");
            System.out.println("");
            System.out.print("Connecting[");
            System.out.println("URL:" + url + " USER:" + usr + " PASS:" + pwd + "]");
            System.out.println("");
            System.err.println("");
            Connection conn = DriverManager.getConnection(url, usr, pwd);
            System.out.println("CONNECT SUCCESS");
            System.out.println("");
            if (query.length() > 0)
            {
                Statement stmt = conn.createStatement();
                ResultSet rs = stmt.executeQuery(query);
                ResultSetMetaData rsmd = rs.getMetaData();
                int columns = rsmd.getColumnCount();
                while(rs.next())
                {
                    for (int i = 0 ; i < columns ; i++)
                    {
                        System.out.println(rsmd.getColumnName(i+1) + " : " + rs.getObject(i + 1));
                    }
                }
                rs.close();
                stmt.close();
                System.out.println("QUERY SUCCESS");
            }
            conn.close();


        } catch (Exception e) { 
            System.err.println("FAILURE: " +  e.getMessage() + " [" + e.getClass().getName() + "]"); 
            //e.printStackTrace();
        } 
        System.out.println("------------------------------------------------------------");
        System.out.println("");
    } 
} 